==> v0.5.4.tar.gz: libarea/app/Languages/en/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'More',
    'category'          => 'Category',
    'categories'        => 'Categories',
    'audits'            => 'Audit',
    'soft'              => 'Soft',
    'website'           => 'Website',
    'websites'          => 'Sites',
    'on_website'        => 'To the website',
    'deleted'           => 'Remote',
    'facets'            => 'Facets',
    'favorites'         => 'Bookmarks',
    'menu'              => 'Menu',
    'no'                => 'No',
    'yes'               => 'Yes',
    'title'             => 'Name',
    'description'       => 'Description',
    'catalog'           => 'Catalog',
    'find'              => 'To find',
    'help'              => 'Clue',
    'deny_replies'      => 'Deny replies?',
    'posted'            => 'Posted?',
    'necessarily'       => 'Required to fill out',
    'status'            => 'Link Status',
    'there_program'     => 'There is a program?',
    'there_forum'       => 'The site has a forum?',
    'there_portal'      => 'Is this a portal?',
    'there_blog'        => 'Is this a personal blog?',
    'there_reference'   => 'Is this a reference site (encyclopedia)?',
    'there_goods'       => 'Does the website offer products and services?',
    'hosted_github'     => 'The program is hosted on GitHub?',
    'url_github'        => 'GitHub repository URL',
    'related_posts'     => 'Related posts',
    'desc_formed'       => 'Description is formed',
    'by_date'           => 'By date',
    'top_view'          => 'By rating',
    'new_sites'         => 'New sites',
    'audits_view'       => 'Require consideration',
    'deleted_view'      => 'Removed',
    'my_website'        => 'My sites',
    'no_website'        => 'No sites yet',
    'bookmarks'         => 'My site bookmarks',
    'bookmarks_view'    => 'My bookmarks',
    'no_bookmarks'      => 'No bookmarks yet',
    'answers'           => 'Answers',
    'no_answers'        => 'No answers yet...',
    'characters'        => 'Characters',
    'remove'            => 'Rmove',
    'reply'             => 'Reply',
    'edit'              => 'Edit',
    'cancel'            => 'Сancel',
    'add'               => 'Add',
    'markdown'          => 'Markdown markup',
    'recommended'       => 'Recommended',
    'my_website_info'   => 'List of sites added by me',
    'moderation'        => 'Moderation',
    'sign_in'           => 'Sign in',
    'registration'      => 'Registration',
    'site_added'        => 'Site added',

    'closed'            => 'Discussion of the site is prohibited. Author or staff closed discussion.',

    'screenshot_time'   => 'Taking a screenshot may take some time.',

    'audits_home_title' => 'Website audit',
    'audits_home_desc'  => 'Sites under consideration',
    'num_website'       => ['Site', 'Sites', 'Sites'],
    
    'news'              => 'News and Media',
    'internet'          => 'Internet',
    'culture'           => 'Culture and art',
    'software'          => 'Programs',
    'reference_info'    => 'Reference Information',
    'reference_help'    => 'Encyclopedias, reference books',
    'science'           => 'Science and education',
    'business'          => 'Business',
    'life'              => 'Home',
    'cms'               => 'CMS',
    'life_help'         => 'Children, animals, hobbies...',
    'security'          => 'Security...',
    'society'           => 'Society and politics',

    'contact_information'   => 'Contact Information',
    'telephone'             => 'Telephone',
    'email'                 => 'Email',
    'vk'                    => 'Vkontakte (URL)',
    'telegram'              => 'Telegram (URL)',

    'string_length'         => 'Incorrect length {name}',
    'website_correctness'   => 'The address (URL) of the site is not correct',
    'site_replay'           => 'Such a site already exists in the system',

    'data_help'         => '<i class="gray-600">Title Format:</i><br> «LibArea» — community<br><br><i class="gray-600">Description (no ads)):</i><br> ...what is on the site?<i>',
    
    'add_category'      => 'Add category',
    'add_website'       => 'Add site',
    'edit_website'      => 'Edit site',
    
    'sidebar_info'      => 'Catalog of sites systematized by thematic headings.',
    'banner_info'       => 'Catalog of sites with annotations and screenshots. <br> Faceted rubrication, search. Bookmarks on resources with the ability to vote for sites, programs, rating',
    
    'main_title'        => 'Website directory',
    'main_desc'         => 'List of sites in the directory placed in chronological order. Ability to search, bookmark, sort by popularity',
    
    'deleted_title'     => 'Remote Sites',
    'deleted_desc'      => '...',
    'audits_title'      => 'Website audit',
    'audits_desc'       => '...',

    'all'               => 'All',
    'github'            => 'GitHub',
    'forum'             => 'Forums',
    'blog'              => 'Blogs',
    'portal'            => 'Portals',
    'reference'         => 'Encyclopedias',
    'goods'             => 'Goods and services',

    'top_title'         => '{name} — sites by popularity',
    'top_desc'          => 'Announced list of sites by subject {description_info}',
    'all_title'         => '{name} — rubric, sites by date',
    'all_desc'          => 'Sites in chronological order in the rubric {description_info}',
];

==> v0.5.6.tar.gz: libarea/app/Languages/en/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'More',
    'category'          => 'Category',
    'categories'        => 'Categories',
    'audits'            => 'Audit',
    'soft'              => 'Soft',
    'website'           => 'Website',
    'websites'          => 'Sites',
    'comments'          => 'Comments',
    'on_website'        => 'To the website',
    'deleted'           => 'Remote',
    'facets'            => 'Facets',
    'favorites'         => 'Bookmarks',
    'menu'              => 'Menu',
    'no'                => 'No',
    'yes'               => 'Yes',
    'title'             => 'Name',
    'description'       => 'Description',
    'catalog'           => 'Catalog',
    'find'              => 'To find',
    'help'              => 'Clue',
    'deny_replies'      => 'Deny replies?',
    'posted'            => 'Posted?',
    'necessarily'       => 'Required to fill out',
    'status'            => 'Status',
    'refresh'           => 'Refresh',
    'there_program'     => 'There is a program?',
    'there_forum'       => 'The site has a forum?',
    'there_portal'      => 'Is this a portal?',
    'there_blog'        => 'Is this a personal blog?',
    'there_reference'   => 'Is this a reference site (encyclopedia)?',
    'there_goods'       => 'Does the website offer products and services?',
    'hosted_github'     => 'The program is hosted on GitHub?',
    'url_github'        => 'GitHub repository URL',
    'related_posts'     => 'Related posts',
    'desc_formed'       => 'Description is formed',
    'by_date'           => 'By date',
    'top'               => 'TOP',
    'top_view'          => 'By rating',
    'new_sites'         => 'New sites',
    'audits_view'       => 'Require consideration',
    'deleted_view'      => 'Removed',
    'my_website'        => 'My sites',
    'no_website'        => 'No sites yet',
    'bookmarks'         => 'My site bookmarks',
    'bookmarks_view'    => 'My bookmarks',
    'no_bookmarks'      => 'No bookmarks yet',
    'answers'           => 'Answers',
    'no_answers'        => 'No answers yet...',
    'characters'        => 'Characters',
    'remove'            => 'Rmove',
    'reply'             => 'Reply',
    'edit'              => 'Edit',
    'cancel'            => 'Сancel',
    'add'               => 'Add',
    'markdown'          => 'Markdown markup',
    'recommended'       => 'Recommended',
    'my_website_info'   => 'List of sites added by me',
    'moderation'        => 'Moderation',
    'sign_in'           => 'Sign in',
    'registration'      => 'Registration',
    'site_added'        => 'Site added',

    'closed'            => 'Discussion of the site is prohibited. Author or staff closed discussion.',

    'screenshot_time'   => 'Taking a screenshot may take some time.',

    'audits_home_title' => 'Website audit',
    'audits_home_desc'  => 'Sites under consideration',
    'num_website'       => ['Site', 'Sites', 'Sites'],
    
    'news'              => 'News and Media',
    'internet'          => 'Internet',
    'culture'           => 'Culture and art',
    'software'          => 'Programs',
    'reference_info'    => 'Reference Information',
    'reference_help'    => 'Encyclopedias, reference books',
    'science'           => 'Science and education',
    'business'          => 'Business',
    'life'              => 'Home',
    'cms'               => 'CMS',
    'life_help'         => 'Children, animals, hobbies...',
    'security'          => 'Security...',
    'society'           => 'Society and politics',

    'contact_information'   => 'Contact Information',
    'telephone'             => 'Telephone',
    'email'                 => 'Email',
    'vk'                    => 'Vkontakte (URL)',
    'telegram'              => 'Telegram (URL)',

    'string_length'         => 'Incorrect length {name}',
    'website_correctness'   => 'The address (URL) of the site is not correct',
    'site_replay'           => 'Such a site already exists in the system',

    'data_help'         => '<i class="gray-600">Title Format:</i><br> «LibArea» — community<br><br><i class="gray-600">Description (no ads)):</i><br> ...what is on the site?<i>',
    'admin_help'         => 'Closed section available only to staff...',
    
    'add_category'      => 'Add category',
    'add_website'       => 'Add site',
    'edit_website'      => 'Edit site',
    
    'sidebar_info'      => 'Catalog of sites systematized by thematic headings.',
    'banner_info'       => 'Catalog of sites with annotations and screenshots. <br> Faceted rubrication, search. Bookmarks on resources with the ability to vote for sites, programs, rating',
    
    'main_title'        => 'Website directory',
    'main_desc'         => 'List of sites in the directory placed in chronological order. Ability to search, bookmark, sort by popularity',
    
    'deleted_title'     => 'Remote Sites',
    'audits_title'      => 'Website audit',

    'all'               => 'All',
    'github'            => 'GitHub',
    'forum'             => 'Forums',
    'blog'              => 'Blogs',
    'portal'            => 'Portals',
    'reference'         => 'Encyclopedias',
    'goods'             => 'Goods and services',

    'top_title'         => '{name} — sites by popularity',
    'top_desc'          => 'Announced list of sites by subject {description_info}',
    'all_title'         => '{name} — rubric, sites by date',
    'all_desc'          => 'Sites in chronological order in the rubric {description_info}',
];
